@@ -120,12 +120,34 @@ send_dbus_signal (Animation_WallpaperPrivate *priv,
                   const gchar *member)
 {
   gboolean       success;
+/*    
+  gint param = 0;
+  dbus_uint32_t serial = 0;
+  DBusMessageIter args;
+*/
   
   DBusMessage *message = dbus_message_new (DBUS_MESSAGE_TYPE_SIGNAL);
   dbus_message_set_interface (message, interface);
   dbus_message_set_path (message, path);
   dbus_message_set_member (message, member);
+  /*
+  if (member == LIVEWP_PLAY_LIVEBG_ON_VIEW ||
+      member == LIVEWP_PAUSE_LIVEBG_ON_VIEW){
+      param = priv->view + 1;
+
+      fprintf(stderr, "dbus send try send %s %i\n", member, param);
+      dbus_message_iter_init_append(message, &args);
+      if (!dbus_message_iter_append_basic(&args, DBUS_TYPE_INT32, &param)){
+          fprintf(stderr, "error append param\n");
+      }
+  }
+  if (!dbus_connection_send(priv->dbus_conn_session, message, &serial)){
+      fprintf(stderr, "error send\n");
+  }
+  dbus_connection_flush(priv->dbus_conn_session);
+  */
   success = dbus_connection_send (priv->dbus_conn_session, message, NULL);
+  dbus_connection_flush(priv->dbus_conn_session);
   dbus_message_unref (message);
   
 #if 0
