@@ -27,6 +27,8 @@
 void 
 destroy_scene(AWallpaperPlugin *desktop_plugin)
 {
+    int status = 0;
+     
     if (desktop_plugin->priv->scene){
 	    GSList * tmp = desktop_plugin->priv->scene->actors;
 	    while (tmp != NULL){
@@ -48,15 +50,21 @@ destroy_scene(AWallpaperPlugin *desktop_plugin)
     }
     if (desktop_plugin->priv->podpid > 1){
         kill (desktop_plugin->priv->podpid, SIGTERM);
+        while (TRUE){
+            if (wait(&status) == desktop_plugin->priv->podpid) 
+                break;
+        } 
         desktop_plugin->priv->podpid = -1;
+        desktop_plugin->priv->running = FALSE;
     }
 }
 /*******************************************************************************/
 void
 reload_scene(AWallpaperPlugin *desktop_plugin)
 {
-    /* fprintf(stderr,"Reload scene %s\n", desktop_plugin->priv->theme); */
+     fprintf(stderr,"Reload scene %s\n", desktop_plugin->priv->theme); 
     destroy_scene(desktop_plugin);
+    fill_priv(desktop_plugin->priv);
     init_scene_theme(desktop_plugin);
 }
 /*******************************************************************************/
@@ -169,24 +177,43 @@ bus_call (GstBus *bus, GstMessage *msg, AWallpaperPlugin *desktop_plugin)
 
 /*******************************************************************************/
 void
-init_scene_Xsnow(AWallpaperPlugin *desktop_plugin){
-    fprintf(stderr,"init_scene_Xsnow\n");
-    char* child_argv[128];
+init_scene_External(AWallpaperPlugin *desktop_plugin){
+
+    char* child_argv[2048];
     char *run_string = NULL;
-#if 0
-    fprintf(stderr, "PARAMETR %s\n",  desktop_plugin->priv->theme_string_parametr1);
-    run_string = g_strdup_printf("/usr/bin/mplayer -vo x11 -wid %d %s\n", \
-		                 GDK_WINDOW_XID(desktop_plugin->priv->window->window), desktop_plugin->priv->theme_string_parametr1);
-#endif
+    gchar *exec_path = NULL,
+        *window_id = NULL,
+        *view = NULL,
+        *strwin = NULL,
+        *strview =NULL;
     if (!desktop_plugin->priv->visible)
         return;
-    run_string= g_strdup_printf("/usr/bin/xsnow");
+    
+    fprintf(stderr,"init_scene_external 111\n");
+    exec_path = g_strdup(g_hash_table_lookup(desktop_plugin->priv->hash_theme, "exec_path"));
+    window_id = g_strdup(g_hash_table_lookup(desktop_plugin->priv->hash_theme, "window_id"));
+    view = g_strdup(g_hash_table_lookup(desktop_plugin->priv->hash_theme, "view"));
+    fprintf(stderr,"init_scene_external 222\n");
+    if (!exec_path) 
+        return;
+    if (window_id){
+        strwin = g_strdup_printf(" %s %i", window_id, (gint)GDK_WINDOW_XID(desktop_plugin->priv->window->window));
+    }else
+        strwin = "";
+
+    if (view){
+        strview = g_strdup_printf(" %s %i", view, desktop_plugin->priv->view);
+    }else
+        strview = "";
+
+    run_string = g_strdup_printf("%s%s%s", exec_path, strwin, strview);
+    fprintf(stderr, "runs string = %s\n", run_string);
     parsestring(run_string, child_argv);
 
     desktop_plugin->priv->running = TRUE;
     desktop_plugin->priv->podpid = fork();
     if (desktop_plugin->priv->podpid == 0){
-    	execvp("/usr/bin/xsnow", child_argv);
+    	execvp(child_argv[0], child_argv);
     	fprintf(stderr,"Problem with new podprocess");
     }
     g_free(run_string);
@@ -869,9 +896,18 @@ init_scene_Berlin(AWallpaperPlugin *desktop_plugin)
 void 
 init_scene_theme(AWallpaperPlugin *desktop_plugin)
 {
+#if 0
     void (*func)(gpointer);
     func = g_hash_table_lookup(desktop_plugin->priv->hash_scene_func, desktop_plugin->priv->theme);
     if (func){
         (*func)(desktop_plugin);
     }
+#endif
+    fprintf(stderr, "Init_scene_theme\n");
+    void (*func)(gpointer);
+    func = desktop_plugin->priv->scene_func;
+    if (func){
+        fprintf(stderr, "Success init_scene_theme\n");
+        (*func)(desktop_plugin);
+    }
 }
