@@ -34,7 +34,7 @@ void lw_about(void){
     gtk_window_set_position(GTK_WINDOW(window), GTK_WIN_POS_CENTER);
     gtk_window_set_modal(GTK_WINDOW(window), TRUE);
     vbox = gtk_vbox_new (FALSE, 5);
-    label_about = gtk_label_new (_("Live Wallpaper Version 0.7.1 \n Copyright(c) 2010\n \
+    label_about = gtk_label_new (_("Live Wallpaper Version 0.8 \n Copyright(c) 2010\n \
 Tanya Makova\n Vlad Vasiliev\n \
 Copyright(c) 2010 for design themes Berlin, Modern and Accel Vasya Bobrikov\n \
 Copyright(c) 2010 for design theme Matrix Andrew Zhilin\n \
@@ -54,19 +54,31 @@ Russian - Tanya Makova \n \
 }
 /*******************************************************************************/
 GtkWidget *
-create_theme_selector (void){
-      GtkWidget *selector;
+create_category_selector (Animation_WallpaperPrivate *priv){
+    GtkWidget *selector;
+    GSList *store = priv->extheme_list;
+    GList *category_list;
+    GHashTable *result_table = NULL;
 
-      selector = hildon_touch_selector_new_text ();
+    result_table = g_hash_table_new(g_str_hash, g_str_equal);
+    while (store){  
+        if (!g_hash_table_lookup(result_table, g_hash_table_lookup(store->data, "category")))
+            g_hash_table_insert(result_table, g_hash_table_lookup(store->data, "category"), (gint *)1);     
+        store = g_slist_next(store);
+    }
 
-      hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), _("Berlin"));
-      hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), _("Modern"));
-      hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), _("Matrix"));
-      hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), _("Accel"));
-      hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), _("Video"));
-      hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), _("Xsnow"));
-      return selector;
+    category_list = g_hash_table_get_keys (result_table);
+    selector = hildon_touch_selector_new_text();
+
+    hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), "LiveWallpaper" );
+    while (category_list){  
+        hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector),category_list->data );
+        category_list = g_list_next(category_list);
+    }
+
+    return selector;
 }
+
 /*******************************************************************************/
 void
 theme_button_clicked(GtkButton *button, Animation_WallpaperPrivate *priv){
@@ -75,22 +87,44 @@ theme_button_clicked(GtkButton *button, Animation_WallpaperPrivate *priv){
 }
 /********************************************************************************/
 void
-set_button_image(GtkWidget * button, gchar *theme, gboolean enable){
+set_button_image(GtkWidget * button, Animation_WallpaperPrivate *priv, gboolean enable){
     GtkWidget * image = NULL; 
     GdkPixbuf * pixbuf = NULL;
     gchar *str = NULL;
-    if (enable)
-        str = g_strdup_printf( "%s/%s/%s", THEME_PATH, 
-                        theme, "icon.png");
-    else 
-        str = g_strdup_printf( "%s/%s/%s", THEME_PATH, 
-                        theme, "icond.png");
+    gchar *icon_on = NULL;
+    gchar *icon_off = NULL;
+    GSList *store = priv->extheme_list;
+    while (store){
+        if (!strcmp(priv->theme, g_hash_table_lookup(store->data, "name"))){
+            icon_on = g_strdup(g_hash_table_lookup(store->data, "icon_on"));
+            icon_off = g_strdup(g_hash_table_lookup(store->data, "icon_off"));
+            break;
+        }
+        store = (GSList *)g_list_next(store);
+    }
+    if (enable){
+        if (icon_on)
+            str = g_strdup_printf("%s", icon_on);
+        else 
+            str = g_strdup_printf( "%s/%s/%s", THEME_PATH, 
+                            priv->theme, "icon.png");
+    }else {
+        if (icon_off)
+            str = g_strdup_printf("%s", icon_off);
+        else
+            str = g_strdup_printf( "%s/%s/%s", THEME_PATH, 
+                            priv->theme, "icond.png");
+    }
     pixbuf = gdk_pixbuf_new_from_file_at_size (str, 
-                                             100, 
-                                             60, 
-                                             NULL);
+                                                 100, 
+                                                 60, 
+                                                 NULL);
     if (str)
         g_free(str);
+    if (icon_on)
+        g_free(icon_on);
+    if (icon_off)
+        g_free(icon_off);
     if (pixbuf){
         image = gtk_image_new_from_pixbuf (pixbuf);
         g_object_unref(G_OBJECT(pixbuf));
@@ -104,6 +138,9 @@ create_image_button (gint view, DBusConnection *conn_sess){
     GtkWidget *button;
     
     Animation_WallpaperPrivate *priv = g_new0(Animation_WallpaperPrivate, 1);
+    /* Add external themes to priv */
+    priv->extheme_list = get_list_exthemes();
+
     priv->view = view;
     priv->theme_string_parametr1 = NULL;
     priv->dbus_conn_session = conn_sess;
@@ -112,7 +149,7 @@ create_image_button (gint view, DBusConnection *conn_sess){
                                     HILDON_BUTTON_ARRANGEMENT_VERTICAL);
     g_object_set_data(G_OBJECT(button), "view", GINT_TO_POINTER(view));
     g_object_set_data(G_OBJECT(button), "priv", priv);
-    set_button_image(button, priv->theme, check_applet_state(view));
+    set_button_image(button, priv, check_applet_state(view));
     g_signal_connect(button, "clicked", G_CALLBACK(theme_button_clicked), priv);
     hildon_button_set_image_position (HILDON_BUTTON (button), GTK_POS_RIGHT);
     return button;
@@ -126,8 +163,9 @@ changed_value_theme_cb (HildonPickerButton *picker, Animation_WallpaperPrivate *
     GtkWidget *vbox = NULL;
         
     vbox = g_object_get_data(G_OBJECT(priv->window), "custom_vbox");
-    if (vbox)
+    if (vbox){
         gtk_widget_destroy(vbox);
+    }
     vbox = gtk_vbox_new (FALSE, 5);
     g_object_set_data(G_OBJECT(priv->window), "custom_vbox", vbox);
     gtk_box_pack_start(GTK_BOX(GTK_DIALOG(priv->window)->vbox),
@@ -142,9 +180,6 @@ changed_value_theme_cb (HildonPickerButton *picker, Animation_WallpaperPrivate *
         if (!strcmp(choice, _("Matrix"))){
             rich_animation_additional_parametr(vbox,priv);
         }
-        if (!strcmp(choice, _("Xsnow"))){
-            rich_animation_additional_parametr(vbox,priv);
-        }
 
         if (!strcmp(choice, _("Accel"))){
             rich_animation_additional_parametr(vbox,priv);
@@ -155,46 +190,150 @@ changed_value_theme_cb (HildonPickerButton *picker, Animation_WallpaperPrivate *
     }
     gtk_widget_show(vbox);
 }
+/********************************************************************************/
+void
+changed_value_category_cb (HildonPickerButton *picker, Animation_WallpaperPrivate *priv)
+{
+    GtkWidget *theme_button = NULL;
 
+    theme_button = g_object_get_data(G_OBJECT(priv->window), "theme_button");
+    if (!theme_button) 
+        return;
+    HildonTouchSelector * selector =  hildon_picker_button_get_selector((HildonPickerButton *) theme_button);
+    hildon_touch_selector_remove_column(selector, 0); 
+    hildon_touch_selector_append_text_column(selector, (GtkTreeModel*)gtk_list_store_new (1, G_TYPE_STRING), TRUE);
+    fill_theme_button(priv, theme_button, (gchar *)hildon_button_get_value(HILDON_BUTTON (picker)));
+}
+/********************************************************************************/
+void
+fill_theme_button (Animation_WallpaperPrivate *priv, GtkWidget *button, gchar *category){
+
+    gchar *theme = priv->theme;
+    gint num=0;
+        hildon_button_set_value(HILDON_BUTTON (button), NULL);
+    if (!category){
+        changed_value_theme_cb(HILDON_PICKER_BUTTON (button), priv);
+        return;
+    }
+    GSList *store = priv->extheme_list;
+    HildonTouchSelector * selector =  hildon_picker_button_get_selector((HildonPickerButton *) button);
+    if (!selector)
+        selector = (HildonTouchSelector *)hildon_touch_selector_new_text ();
+    
+    hildon_button_set_value(HILDON_BUTTON(button), NULL);
+    if (!strcmp(category, "LiveWallpaper")){
+        hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), _("Berlin"));
+        hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), _("Modern"));
+        hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), _("Matrix"));
+        hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), _("Accel"));
+        hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), _("Video"));
+        num = 5;        
+        if (theme){ 
+            if (!strcmp(theme, "Berlin")){
+                hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR (selector), 0, 0);
+                hildon_button_set_value(HILDON_BUTTON(button), _("Berlin"));
+            }
+            if (!strcmp(theme, "Modern")){
+                hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR (selector), 0, 1);
+                hildon_button_set_value(HILDON_BUTTON(button), _("Modern"));
+            }
+            if (!strcmp(theme, "Matrix")){
+                hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR (selector), 0, 2);
+                hildon_button_set_value(HILDON_BUTTON(button), _("Matrix"));
+            }
+            if (!strcmp(theme, "Accel")){
+                hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR (selector), 0, 3);
+                hildon_button_set_value(HILDON_BUTTON(button), _("Accel"));
+            }
+            if (!strcmp(theme, "Video")){
+                hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR (selector), 0, 4);
+                hildon_button_set_value(HILDON_BUTTON(button), _("Video"));
+            }
+       }
+    }
+    while (store){  
+        if (!g_hash_table_lookup(store->data, "category"))
+            continue;
+        if (!strcmp(g_hash_table_lookup(store->data, "category"), category)){
+            hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), g_hash_table_lookup(store->data, "name"));
+            if (!strcmp(theme, g_hash_table_lookup(store->data, "name"))){
+                hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR (selector), 0, num);
+                hildon_button_set_value(HILDON_BUTTON(button), _(g_hash_table_lookup(store->data, "name")));
+            }
+            num++;
+        }
+        store = g_slist_next(store);
+    }
+       
+    hildon_picker_button_set_selector (HILDON_PICKER_BUTTON (button),
+                                                       HILDON_TOUCH_SELECTOR (selector));
+
+    changed_value_theme_cb(HILDON_PICKER_BUTTON (button), priv);
+}
 /********************************************************************************/
 GtkWidget *
-create_themes_button (gchar *theme){
+create_themes_button (Animation_WallpaperPrivate *priv, gchar *category){
+
+    GtkWidget *button;
+    button = hildon_picker_button_new (HILDON_SIZE_AUTO, HILDON_BUTTON_ARRANGEMENT_VERTICAL);
+    hildon_button_set_title (HILDON_BUTTON (button), _("Theme"));
+
+   
+    return button;
+}
+/********************************************************************************/
+GtkWidget *
+create_categories_button (Animation_WallpaperPrivate *priv){
 
     GtkWidget *button;
     GtkWidget *selector;
+    gchar *theme = priv->theme;
+    gint num=0;
+    GHashTable *result_table = NULL;
 
-    selector = create_theme_selector();
+    result_table = g_hash_table_new(g_str_hash, g_str_equal);
+    selector = create_category_selector(priv);
     button = hildon_picker_button_new (HILDON_SIZE_AUTO, HILDON_BUTTON_ARRANGEMENT_VERTICAL);
-    hildon_button_set_title (HILDON_BUTTON (button), _("Theme"));
+    hildon_button_set_title (HILDON_BUTTON (button), _("Category"));
     hildon_picker_button_set_selector (HILDON_PICKER_BUTTON (button),
                                                        HILDON_TOUCH_SELECTOR (selector));
     if (theme) {
         if (!strcmp(theme, "Berlin")){
-            hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR (selector), 0, 0);
-            hildon_button_set_value(HILDON_BUTTON(button), _("Berlin"));
+            hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR (selector), 0, 0); 
+            hildon_button_set_value(HILDON_BUTTON(button), "LiveWallpaper");
         }
         if (!strcmp(theme, "Modern")){
-            hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR (selector), 0, 1);
-            hildon_button_set_value(HILDON_BUTTON(button), _("Modern"));
+            hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR (selector), 0, 0); 
+            hildon_button_set_value(HILDON_BUTTON(button), "LiveWallpaper");
         }
         if (!strcmp(theme, "Matrix")){
-            hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR (selector), 0, 2);
-            hildon_button_set_value(HILDON_BUTTON(button), _("Matrix"));
+            hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR (selector), 0, 0); 
+            hildon_button_set_value(HILDON_BUTTON(button), "LiveWallpaper");
         }
         if (!strcmp(theme, "Accel")){
-            hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR (selector), 0, 3);
-            hildon_button_set_value(HILDON_BUTTON(button), _("Accel"));
+            hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR (selector), 0, 0); 
+            hildon_button_set_value(HILDON_BUTTON(button), "LiveWallpaper");
         }
         if (!strcmp(theme, "Video")){
-            hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR (selector), 0, 4);
-            hildon_button_set_value(HILDON_BUTTON(button), _("Video"));
+            hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR (selector), 0, 0); 
+            hildon_button_set_value(HILDON_BUTTON(button), "LiveWallpaper");
         }
-        if (!strcmp(theme, "Xsnow")){
-            hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR (selector), 0, 5);
-            hildon_button_set_value(HILDON_BUTTON(button), _("Xsnow"));
+        GSList *store = priv->extheme_list;
+        while (store){
+            if (!g_hash_table_lookup(result_table, g_hash_table_lookup(store->data, "category"))){
+                g_hash_table_insert(result_table, g_hash_table_lookup(store->data, "category"), (gint *)num);     
+                num++;
+            }
+            if (!strcmp(theme, g_hash_table_lookup(store->data, "name"))){
+                if (g_hash_table_lookup(store->data, "category"))
+                    hildon_button_set_value(HILDON_BUTTON(button), _(g_hash_table_lookup(store->data, "category")));
+                    hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR (selector), 0, (gint)g_hash_table_lookup(result_table, g_hash_table_lookup(store->data, "category"))); 
+                break;
+            }
+
+            store = g_slist_next(store);
         }
     }
-    
     return button;
 }
 
@@ -324,6 +463,7 @@ file_button_clicked(GtkButton *button, Animation_WallpaperPrivate *priv){
 void
 rich_animation_additional_parametr(GtkWidget *vbox, Animation_WallpaperPrivate *priv){
     GtkWidget *rich_animation_button;
+
     /* Create rich animation button */  
     rich_animation_button = create_rich_animation_button(priv->rich_animation, _("Rich Animation"));
     gtk_box_pack_start(GTK_BOX(vbox),
@@ -366,6 +506,7 @@ lw_theme_settings(GtkWidget *button, Animation_WallpaperPrivate *priv) {
     GtkWidget *window = NULL;
     GtkWidget *save_button;
     GtkWidget *theme_button;
+    GtkWidget *category_button;
     GtkWidget *enable_button;
     GtkWidget *vbox;
     GtkWidget *button1 = NULL;
@@ -378,37 +519,39 @@ lw_theme_settings(GtkWidget *button, Animation_WallpaperPrivate *priv) {
     gtk_window_set_title(GTK_WINDOW(window), _("View Settings"));
     gtk_window_set_position(GTK_WINDOW(window), GTK_WIN_POS_CENTER);
     gtk_window_set_modal(GTK_WINDOW(window), TRUE);
+
     /* Create Enable button */
     enable_button = create_enable_button(check_applet_state(view)); 
     gtk_box_pack_start(GTK_BOX(GTK_DIALOG(window)->vbox),
                                    enable_button, TRUE, TRUE, 5);
+    /* Create Category button */
+    category_button = create_categories_button(priv);
+    g_object_set_data(G_OBJECT(window), "category_button", category_button);
+    g_signal_connect (G_OBJECT (category_button), "value-changed",  G_CALLBACK (changed_value_category_cb), priv);
+    gtk_box_pack_start(GTK_BOX(GTK_DIALOG(window)->vbox),
+                                   category_button, TRUE, TRUE, 5);
+    /* Create Custom vbox */
+    vbox = gtk_vbox_new (FALSE, 5);
+    g_object_set_data(G_OBJECT(window), "custom_vbox", vbox);
+
     /* Create Theme button */
-    theme_button = create_themes_button(priv->theme);
+    theme_button = create_themes_button(priv, (gchar *)hildon_button_get_value(HILDON_BUTTON (category_button)));
+    g_object_set_data(G_OBJECT(window), "theme_button", theme_button);
     g_signal_connect (G_OBJECT (theme_button), "value-changed",  G_CALLBACK (changed_value_theme_cb), priv);
     gtk_box_pack_start(GTK_BOX(GTK_DIALOG(window)->vbox),
                                    theme_button, TRUE, TRUE, 5);
+    fill_theme_button(priv, theme_button, (gchar *)hildon_button_get_value(HILDON_BUTTON (category_button)));
 
-    /* Create custom vbox */
-    vbox = gtk_vbox_new (FALSE, 5);
-    g_object_set_data(G_OBJECT(window), "custom_vbox", vbox);
+    /* Pack custom vbox. It must be last widget */
     gtk_box_pack_start(GTK_BOX(GTK_DIALOG(window)->vbox),
                                    vbox, TRUE, TRUE, 5);
-    if (!strcmp(hildon_button_get_value(HILDON_BUTTON (theme_button)), _("Berlin"))||
-        !strcmp(hildon_button_get_value(HILDON_BUTTON (theme_button)), _("Matrix"))||
-        !strcmp(hildon_button_get_value(HILDON_BUTTON (theme_button)), _("Accel"))||
-        !strcmp(hildon_button_get_value(HILDON_BUTTON (theme_button)), _("Xsnow"))||
-        !strcmp(hildon_button_get_value(HILDON_BUTTON (theme_button)), _("Modern"))){
-        rich_animation_additional_parametr(vbox, priv);
-    }
-
-    if (!strcmp(hildon_button_get_value(HILDON_BUTTON (theme_button)), _("Video"))){
-        additional_parametr_for_theme_video(vbox, priv);
-    } 
 
     gtk_widget_show (enable_button);
+    gtk_widget_show (category_button);
     gtk_widget_show (theme_button);
     gtk_widget_show (vbox);
     gtk_widget_show (window);
+
     save_button = gtk_dialog_add_button(GTK_DIALOG(window), _("Save"), GTK_RESPONSE_YES);
 
     result = gtk_dialog_run(GTK_DIALOG(window));
@@ -416,7 +559,8 @@ lw_theme_settings(GtkWidget *button, Animation_WallpaperPrivate *priv) {
     switch(result){
         case GTK_RESPONSE_YES:
             /* Check theme */
-            if (hildon_button_get_value(HILDON_BUTTON (theme_button))){
+            if (hildon_button_get_value(HILDON_BUTTON (theme_button)) &&
+                strcmp(hildon_button_get_value(HILDON_BUTTON (theme_button)), "")){
                 /* Check Xsnow program */
                 if (!strcmp(hildon_button_get_value(HILDON_BUTTON (theme_button)), _("Xsnow"))){
                     if (access("/usr/bin/xsnow", F_OK) != 0){
@@ -429,7 +573,6 @@ lw_theme_settings(GtkWidget *button, Animation_WallpaperPrivate *priv) {
 
                 if (priv->theme)
                     g_free(priv->theme);
-
                 if (!strcmp(hildon_button_get_value(HILDON_BUTTON (theme_button)), _("Berlin")))
                     priv->theme = g_strdup("Berlin");
                 if (!strcmp(hildon_button_get_value(HILDON_BUTTON (theme_button)), _("Modern")))
@@ -438,8 +581,6 @@ lw_theme_settings(GtkWidget *button, Animation_WallpaperPrivate *priv) {
                     priv->theme = g_strdup("Matrix");
                 if (!strcmp(hildon_button_get_value(HILDON_BUTTON (theme_button)), _("Accel")))
                     priv->theme = g_strdup("Accel");
-                if (!strcmp(hildon_button_get_value(HILDON_BUTTON (theme_button)), _("Xsnow")))
-                    priv->theme = g_strdup("Xsnow");
                 if (!strcmp(hildon_button_get_value(HILDON_BUTTON (theme_button)), _("Video"))){
                     priv->theme = g_strdup("Video");
                     button1 = g_object_get_data(G_OBJECT(priv->window), "filename_button");
@@ -449,6 +590,16 @@ lw_theme_settings(GtkWidget *button, Animation_WallpaperPrivate *priv) {
                         priv->theme_string_parametr1 = g_strdup((gchar*)hildon_button_get_value (HILDON_BUTTON(button1)));
                     }
                 }
+                /* Check external themes */
+                GSList *store = priv->extheme_list;
+                while (store){
+                    if (!strcmp(hildon_button_get_value(HILDON_BUTTON (theme_button)), _(g_hash_table_lookup(store->data, "name")))){
+                        priv->theme = g_strdup(g_hash_table_lookup(store->data, "name"));
+                        //priv->hash_theme = store->data;
+                        break;
+                    }
+                    store = g_slist_next(store);
+                }
 
             }
 
@@ -476,7 +627,7 @@ lw_theme_settings(GtkWidget *button, Animation_WallpaperPrivate *priv) {
                     if (check_applet_state(view))
                         stop_applet(view);
 
-            set_button_image(button, priv->theme, check_applet_state(view));
+            set_button_image(button, priv, check_applet_state(view));
             break;
         default:
         case GTK_RESPONSE_OK:
@@ -510,26 +661,6 @@ check_applet_state(gint number){
         g_free(str);
     }
     return result;
-#if 0
-    FILE    *file_in = NULL;
-    gchar buffer[2048];
-
-    file_in = fopen("/home/user/.config/hildon-desktop/home.plugins","r");
-    if (file_in){
-
-        fprintf(stderr,"Check applet state\n");
-        while (!feof(file_in)) {
-                memset(buffer, 0, sizeof(buffer));
-                fgets(buffer, sizeof(buffer) - 1, file_in);
-                if (!strcmp(buffer, 
-                            "X-Desktop-File=/usr/share/applications/hildon-home/livewp-home-widget.desktop\n")){
-                    result = TRUE;
-                    break;
-                }
-       }
-        fclose(file_in);
-    }
-#endif
 }
 /*******************************************************************************/
 void
@@ -578,40 +709,4 @@ stop_applet(gint number){
         g_free(str);
     g_object_unref(config_file);
 
-#if 0    
-    FILE    *file_in;
-    FILE    *file_out;
-    gchar buffer[2048];
-    gchar * str = NULL;
-
-    file_in = fopen("/home/user/.config/hildon-desktop/home.plugins","r");
-    file_out = fopen("/tmp/livewallpaper.plugins","w");
-    if (file_in && file_out){
-        while (!feof(file_in)) {
-            memset(buffer, 0, sizeof(buffer));
-            fgets(buffer, sizeof(buffer) - 1, file_in);
-            str = g_strdup_printf("[livewp-home-widget.desktop-%i]\n", number);
-            if (strcmp(buffer, str) &&
-                strcmp(buffer, "X-Desktop-File=/usr/share/applications/hildon-home/livewp-home-widget.desktop\n"))
-                fputs(buffer, file_out);
-        }
-        if (str){
-            g_free(str);
-        }
-        fclose(file_out);
-        fclose(file_in);
-        file_in = fopen("/tmp/livewallpaper.plugins","r");
-        file_out = fopen("/home/user/.config/hildon-desktop/home.plugins","w");
-        if (file_in && file_out){
-            while (!feof(file_in)){
-                memset(buffer, 0, sizeof(buffer));
-                fgets(buffer, sizeof(buffer) - 1, file_in);
-                fputs(buffer, file_out);
-            }
-            fclose(file_out);
-            fclose(file_in);
-            unlink ("/tmp/livewallpaper.plugins");
-        }
-    }
-#endif
 }
